const express = require('express');
const cors = require('cors');
const path = require('path');
const multer = require('multer');

const app = express();
const port = 4000;

// Enable CORS and JSON parsing
app.use(cors());
app.use(express.json());

// Multer Storage Configuration
const storage = multer.diskStorage({
  destination: './uploads/',
  filename: function (req, file, cb) {
    cb(null, Date.now() + path.extname(file.originalname)); // Ensures unique filenames
  },
});

const upload = multer({ storage });

// Upload Endpoint with Error Handling
app.post('/upload', upload.single('photo'), (req, res) => {
  console.log('Received a POST request:', req.body);
  console.log('Received file:', req.file);

  if (!req.file) {
    return res.status(400).json({ error: 'No file uploaded' });
  }

  const photoUrl = `${req.protocol}://${req.get('host')}/uploads/${req.file.filename}`;
  res.json({ photoUrl }); // Proper JSON response
});

// Serve Uploaded Files
app.use('/uploads', express.static('uploads'));

// Root Route (Prevents "Cannot GET /" Error)
app.get('/', (req, res) => {
  res.send('Server is running');
});

// Start Server
app.listen(port, () => {
  console.log(`Server running on http://192.168.68.112:${port}`);
});
